@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2014 Zabbix SIA
+** Copyright (C) 2001-2015 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -777,6 +777,7 @@ elseif (isset($_REQUEST['form'])) {
 			'output' => API_OUTPUT_EXTEND
 		));
 		$dbHost = reset($dbHosts);
+		order_result($dbHost['groups'], 'name');
 
 		$dbHost['interfaces'] = API::HostInterface()->get(array(
 			'hostids' => $hostId,
@@ -943,6 +944,8 @@ else {
 		));
 	}
 
+	$currentTime = time();
+
 	foreach ($hosts as $host) {
 		$interface = reset($host['interfaces']);
 
@@ -1055,7 +1058,7 @@ else {
 			$hostInterface,
 			new CCol($hostTemplates, 'wraptext'),
 			$status,
-			getAvailabilityTable($host)
+			getAvailabilityTable($host, $currentTime)
 		));
 	}
 
