@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2014 Zabbix SIA
+** Copyright (C) 2001-2015 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -289,7 +289,7 @@ function getMenuPopupHost(options) {
  * @param array  options['gotos']['showTriggers']	display "Triggers" link enabled or disabled
  * @param array  options['gotos']['submap']			link to submap page with url parameters ("name" => "value")
  * @param array  options['gotos']['events']			link to events page with url parameters ("name" => "value")
- * @param array  options['gotos']['showEvents']		display "Latest events" link enabled or disabled
+ * @param array  options['gotos']['showEvents']		display "Events" link enabled or disabled
  * @param array  options['urls']					local and global map urls (optional)
  * @param string options['url'][]['label']			url label
  * @param string options['url'][]['url']			url
@@ -402,14 +402,14 @@ function getMenuPopupMap(options) {
 
 		// events
 		if (typeof options.gotos.events !== 'undefined') {
-			var url = new Curl('events.php?source=0');
+			var url = new Curl('events.php?filter_set=1&source=0');
 
 			jQuery.each(options.gotos.events, function(name, value) {
 				url.setArgument(name, value);
 			});
 
 			gotos[gotos.length] = {
-				label: t('Latest events'),
+				label: t('Events'),
 				css: options.gotos.showEvents ? '' : 'ui-state-disabled',
 				url: url.getUrl()
 			};
@@ -570,7 +570,7 @@ function getMenuPopupServiceConfiguration(options) {
  * Get menu popup trigger section data.
  *
  * @param string options['triggerid']				trigger id
- * @param array  options['items']					link to trigger item history page (optional)
+ * @param object options['items']					link to trigger item history page (optional)
  * @param string options['items'][]['name']			item name
  * @param object options['items'][]['params']		item url parameters ("name" => "value")
  * @param object options['acknowledge']				link to acknowledge page (optional)
@@ -587,14 +587,14 @@ function getMenuPopupTrigger(options) {
 	var sections = [], items = [];
 
 	// events
-	var url = new Curl('events.php?filter_set=1&triggerid=' + options.triggerid + '&source=0');
+	var url = new Curl('events.php?filter_set=1&source=0&triggerid=' + options.triggerid);
 	if (typeof options.eventTime !== 'undefined') {
 		url.setArgument('nav_time', options.eventTime);
 	}
 
 	items[items.length] = {
 		label: t('Events'),
-		css: options.showEvents ? '' : 'ui-state-disabled',
+		css: (typeof options.showEvents !== 'undefined' && options.showEvents) ? '' : 'ui-state-disabled',
 		url: url.getUrl()
 	};
 
@@ -613,9 +613,8 @@ function getMenuPopupTrigger(options) {
 	}
 
 	// configuration
-	if (typeof options.configuration !== 'undefined' && options.configuration !== null) {
-		var url = new Curl('triggers.php?triggerid=' + options.triggerid + '&hostid=' + options.configuration.hostid
-				+ '&form=update');
+	if (typeof options.configuration !== 'undefined' && options.configuration) {
+		var url = new Curl('triggers.php?form=update&triggerid=' + options.triggerid);
 
 		items[items.length] = {
 			label: t('Configuration'),
@@ -637,7 +636,7 @@ function getMenuPopupTrigger(options) {
 	};
 
 	// items
-	if (typeof options.items !== 'undefined' && options.items.length > 0) {
+	if (typeof options.items !== 'undefined' && objectSize(options.items) > 0) {
 		var items = [];
 
 		jQuery.each(options.items, function(i, item) {
